==> com.liferay.site.navigation.admin.web-3.0.24.jar: META-INF/resources/site_navigation_menu_editor/contexts/SidebarPanelIdContext.js <==
Liferay.Loader.define("site-navigation-admin-web@3.0.24/site_navigation_menu_editor/contexts/SidebarPanelIdContext", ['module', 'exports', 'require', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.SidebarPanelIdProvider = exports.useSidebarPanelId = exports.useSetSidebarPanelId = void 0;

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { "default": obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj["default"] = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var SidebarPanelIdContext = _react["default"].createContext({});

    var SetSidebarPanelIdContext = _react["default"].createContext({});

    var useSetSidebarPanelId = function useSetSidebarPanelId() {
      return (0, _react.useContext)(SetSidebarPanelIdContext);
    };

    exports.useSetSidebarPanelId = useSetSidebarPanelId;

    var useSidebarPanelId = function useSidebarPanelId() {
      return (0, _react.useContext)(SidebarPanelIdContext);
    };

    exports.useSidebarPanelId = useSidebarPanelId;

    var SidebarPanelIdProvider = function SidebarPanelIdProvider(_ref) {
      var children = _ref.children,
          _ref$initialSidebarPa = _ref.initialSidebarPanelId,
          initialSidebarPanelId = _ref$initialSidebarPa === void 0 ? null : _ref$initialSidebarPa;

      var _useState = (0, _react.useState)(initialSidebarPanelId),
          _useState2 = _slicedToArray(_useState, 2),
          sidebarPanelId = _useState2[0],
          setSidebarPanelId = _useState2[1];

      return _react["default"].createElement(SetSidebarPanelIdContext.Provider, {
        value: setSidebarPanelId
      }, _react["default"].createElement(SidebarPanelIdContext.Provider, {
        value: sidebarPanelId
      }, children));
    };

    exports.SidebarPanelIdProvider = SidebarPanelIdProvider;
    SidebarPanelIdContext.propTypes = {
      setSidebarPanelId: _propTypes["default"].func
    };
    //# sourceMappingURL=SidebarPanelIdContext.js.map
  }
});
//# sourceMappingURL=SidebarPanelIdContext.js.map

==> com.liferay.site.navigation.admin.web-3.0.35.jar: META-INF/resources/site_navigation_menu_editor/contexts/SidebarPanelIdContext.js <==
Liferay.Loader.define("site-navigation-admin-web@3.0.35/site_navigation_menu_editor/contexts/SidebarPanelIdContext", ['module', 'exports', 'require', 'frontend-js-react-web$prop-types', 'frontend-js-react-web$react'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.SidebarPanelIdProvider = exports.useSidebarPanelId = exports.useSetSidebarPanelId = void 0;

    var _propTypes = _interopRequireDefault(require("frontend-js-react-web$prop-types"));

    var _react = _interopRequireWildcard(require("frontend-js-react-web$react"));

    function _getRequireWildcardCache() {
      if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
        return cache;
      };return cache;
    }

    function _interopRequireWildcard(obj) {
      if (obj && obj.__esModule) {
        return obj;
      }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
        return { default: obj };
      }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
        return cache.get(obj);
      }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
        if (Object.prototype.hasOwnProperty.call(obj, key)) {
          var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
            Object.defineProperty(newObj, key, desc);
          } else {
            newObj[key] = obj[key];
          }
        }
      }newObj.default = obj;if (cache) {
        cache.set(obj, newObj);
      }return newObj;
    }

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _slicedToArray(arr, i) {
      return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
    }

    function _nonIterableRest() {
      throw new TypeError("Invalid attempt to destructure non-iterable instance");
    }

    function _iterableToArrayLimit(arr, i) {
      if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
        return;
      }var _arr = [];var _n = true;var _d = false;var _e = undefined;try {
        for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
          _arr.push(_s.value);if (i && _arr.length === i) break;
        }
      } catch (err) {
        _d = true;_e = err;
      } finally {
        try {
          if (!_n && _i["return"] != null) _i["return"]();
        } finally {
          if (_d) throw _e;
        }
      }return _arr;
    }

    function _arrayWithHoles(arr) {
      if (Array.isArray(arr)) return arr;
    }

    var SidebarPanelIdContext = /*#__PURE__*/_react.default.createContext(null);

    var SetSidebarPanelIdContext = /*#__PURE__*/_react.default.createContext(function () {});

    var useSetSidebarPanelId = function useSetSidebarPanelId() {
      return (0, _react.useContext)(SetSidebarPanelIdContext);
    };

    exports.useSetSidebarPanelId = useSetSidebarPanelId;

    var useSidebarPanelId = function useSidebarPanelId() {
      return (0, _react.useContext)(SidebarPanelIdContext);
    };

    exports.useSidebarPanelId = useSidebarPanelId;

    var SidebarPanelIdProvider = function SidebarPanelIdProvider(_ref) {
      var children = _ref.children,
          _ref$initialSidebarPa = _ref.initialSidebarPanelId,
          initialSidebarPanelId = _ref$initialSidebarPa === void 0 ? null : _ref$initialSidebarPa;

      var _useState = (0, _react.useState)(initialSidebarPanelId),
          _useState2 = _slicedToArray(_useState, 2),
          sidebarPanelId = _useState2[0],
          setSidebarPanelId = _useState2[1];

      return (/*#__PURE__*/_react.default.createElement(SetSidebarPanelIdContext.Provider, {
          value: setSidebarPanelId
        }, /*#__PURE__*/_react.default.createElement(SidebarPanelIdContext.Provider, {
          value: sidebarPanelId
        }, children))
      );
    };

    exports.SidebarPanelIdProvider = SidebarPanelIdProvider;
    SidebarPanelIdContext.propTypes = {
      setSidebarPanelId: _propTypes.default.func
    };
    //# sourceMappingURL=SidebarPanelIdContext.js.map
  }
});
//# sourceMappingURL=SidebarPanelIdContext.js.map
